pub enum CreateChangeSetError {
AlreadyExists(String),
InsufficientCapabilities(String),
LimitExceeded(String),
}Expand description
Errors returned by CreateChangeSet
Variants
AlreadyExists(String)
The resource with the name requested already exists.
InsufficientCapabilities(String)
The template contains resources with capabilities that weren't specified in the Capabilities parameter.
LimitExceeded(String)
The quota for the resource has already been reached.
For information on resource and stack limitations, see Limits in the AWS CloudFormation User Guide.
Implementations
Sourceimpl CreateChangeSetError
impl CreateChangeSetError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<CreateChangeSetError>