pub enum UpdateStackInstancesError {
InvalidOperation(String),
OperationIdAlreadyExists(String),
OperationInProgress(String),
StackInstanceNotFound(String),
StackSetNotFound(String),
StaleRequest(String),
}Expand description
Errors returned by UpdateStackInstances
Variants
InvalidOperation(String)
The specified operation isn't valid.
OperationIdAlreadyExists(String)
The specified operation ID already exists.
OperationInProgress(String)
Another operation is currently in progress for this stack set. Only one operation can be performed for a stack set at a given time.
StackInstanceNotFound(String)
The specified stack instance doesn't exist.
StackSetNotFound(String)
The specified stack set doesn't exist.
StaleRequest(String)
Another operation has been performed on this stack set since the specified operation was performed.
Implementations
Sourceimpl UpdateStackInstancesError
impl UpdateStackInstancesError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<UpdateStackInstancesError>