pub struct CancelUpdateStackInput {
pub client_request_token: Option<String>,
pub stack_name: String,
}Expand description
The input for the CancelUpdateStack action.
Fields
client_request_token: Option<String>A unique identifier for this CancelUpdateStack request. Specify this token if you plan to retry requests so that AWS CloudFormation knows that you're not attempting to cancel an update on a stack with the same name. You might retry CancelUpdateStack requests to ensure that AWS CloudFormation successfully received them.
stack_name: StringThe name or the unique stack ID that is associated with the stack.