pub struct DescribeStackEventsInput {
pub next_token: Option<String>,
pub stack_name: Option<String>,
}Expand description
The input for DescribeStackEvents action.
Fields
next_token: Option<String>A string that identifies the next page of events that you want to retrieve.
stack_name: Option<String>The name or the unique stack ID that is associated with the stack, which are not always interchangeable:
-
Running stacks: You can specify either the stack's name or its unique stack ID.
-
Deleted stacks: You must specify the unique stack ID.
Default: There is no default value.