pub struct DescribeStackEventsOutput {
pub next_token: Option<String>,
pub stack_events: Option<Vec<StackEvent>>,
}Expand description
The output for a DescribeStackEvents action.
Fields
next_token: Option<String>If the output exceeds 1 MB in size, a string that identifies the next page of events. If no additional page exists, this value is null.
stack_events: Option<Vec<StackEvent>>A list of StackEvents structures.