pub struct DescribeStackResourceInput {
pub logical_resource_id: String,
pub stack_name: String,
}Expand description
The input for DescribeStackResource action.
Fields
logical_resource_id: StringThe logical name of the resource as specified in the template.
Default: There is no default value.
stack_name: StringThe name or the unique stack ID that is associated with the stack, which are not always interchangeable:
-
Running stacks: You can specify either the stack's name or its unique stack ID.
-
Deleted stacks: You must specify the unique stack ID.
Default: There is no default value.