pub struct DetectStackResourceDriftInput {
pub logical_resource_id: String,
pub stack_name: String,
}Fields
logical_resource_id: StringThe logical name of the resource for which to return drift information.
stack_name: StringThe name of the stack to which the resource belongs.