pub struct SetStackPolicyInput {
pub stack_name: String,
pub stack_policy_body: Option<String>,
pub stack_policy_url: Option<String>,
}Expand description
The input for the SetStackPolicy action.
Fields
stack_name: StringThe name or unique stack ID that you want to associate a policy with.
stack_policy_body: Option<String>Structure containing the stack policy body. For more information, go to Prevent Updates to Stack Resources in the AWS CloudFormation User Guide. You can specify either the StackPolicyBody or the StackPolicyURL parameter, but not both.
stack_policy_url: Option<String>Location of a file containing the stack policy. The URL must point to a policy (maximum size: 16 KB) located in an S3 bucket in the same Region as the stack. You can specify either the StackPolicyBody or the StackPolicyURL parameter, but not both.