StackEvent

Struct StackEvent 

pub struct StackEvent {
    pub client_request_token: Option<String>,
    pub event_id: String,
    pub logical_resource_id: Option<String>,
    pub physical_resource_id: Option<String>,
    pub resource_properties: Option<String>,
    pub resource_status: Option<String>,
    pub resource_status_reason: Option<String>,
    pub resource_type: Option<String>,
    pub stack_id: String,
    pub stack_name: String,
    pub timestamp: String,
}
The StackEvent data type.

Fields

client_request_token: Option<String>

The token passed to the operation that generated this event.

All events triggered by a given stack operation are assigned the same client request token, which you can use to track operations. For example, if you execute a CreateStack operation with the token token1, then all the StackEvents generated by that operation will have ClientRequestToken set as token1.

In the console, stack operations display the client request token on the Events tab. Stack operations that are initiated from the console use the token format Console-StackOperation-ID, which helps you easily identify the stack operation . For example, if you create a stack using the console, each stack event would be assigned the same token in the following format: Console-CreateStack-7f59c3cf-00d2-40c7-b2ff-e75db0987002.

event_id: String

The unique ID of this event.

logical_resource_id: Option<String>

The logical name of the resource specified in the template.

physical_resource_id: Option<String>

The name or unique identifier associated with the physical instance of the resource.

resource_properties: Option<String>

BLOB of the properties used to create the resource.

resource_status: Option<String>

Current status of the resource.

resource_status_reason: Option<String>

Success/failure message associated with the resource.

resource_type: Option<String>

Type of resource. (For more information, go to AWS Resource Types Reference in the AWS CloudFormation User Guide.)

stack_id: String

The unique ID name of the instance of the stack.

stack_name: String

The name associated with a stack.

timestamp: String

Time the status was updated.