StackInstanceSummary

Struct StackInstanceSummary 

pub struct StackInstanceSummary {
    pub account: Option<String>,
    pub drift_status: Option<String>,
    pub last_drift_check_timestamp: Option<String>,
    pub organizational_unit_id: Option<String>,
    pub region: Option<String>,
    pub stack_id: Option<String>,
    pub stack_instance_status: Option<StackInstanceComprehensiveStatus>,
    pub stack_set_id: Option<String>,
    pub status: Option<String>,
    pub status_reason: Option<String>,
}
The structure that contains summary information about a stack instance.

Fields

account: Option<String>

[Self-managed permissions] The name of the AWS account that the stack instance is associated with.

drift_status: Option<String>

Status of the stack instance's actual configuration compared to the expected template and parameter configuration of the stack set to which it belongs.

  • DRIFTED: The stack differs from the expected template and parameter configuration of the stack set to which it belongs. A stack instance is considered to have drifted if one or more of the resources in the associated stack have drifted.

  • NOTCHECKED: AWS CloudFormation has not checked if the stack instance differs from its expected stack set configuration.

  • INSYNC: The stack instance's actual configuration matches its expected stack set configuration.

  • UNKNOWN: This value is reserved for future use.

last_drift_check_timestamp: Option<String>

Most recent time when CloudFormation performed a drift detection operation on the stack instance. This value will be NULL for any stack instance on which drift detection has not yet been performed.

organizational_unit_id: Option<String>

[Service-managed permissions] The organization root ID or organizational unit (OU) IDs that you specified for DeploymentTargets.

region: Option<String>

The name of the AWS Region that the stack instance is associated with.

stack_id: Option<String>

The ID of the stack instance.

stack_instance_status: Option<StackInstanceComprehensiveStatus>

The detailed status of the stack instance.

stack_set_id: Option<String>

The name or unique ID of the stack set that the stack instance is associated with.

status: Option<String>

The status of the stack instance, in terms of its synchronization with its associated stack set.

  • INOPERABLE: A DeleteStackInstances operation has failed and left the stack in an unstable state. Stacks in this state are excluded from further UpdateStackSet operations. You might need to perform a DeleteStackInstances operation, with RetainStacks set to true, to delete the stack instance, and then delete the stack manually.

  • OUTDATED: The stack isn't currently up to date with the stack set because:

    • The associated stack failed during a CreateStackSet or UpdateStackSet operation.

    • The stack was part of a CreateStackSet or UpdateStackSet operation that failed or was stopped before the stack was created or updated.

  • CURRENT: The stack is currently up to date with the stack set.

status_reason: Option<String>

The explanation for the specific status code assigned to this stack instance.