StackResource

Struct StackResource 

pub struct StackResource {
    pub description: Option<String>,
    pub drift_information: Option<StackResourceDriftInformation>,
    pub logical_resource_id: String,
    pub physical_resource_id: Option<String>,
    pub resource_status: String,
    pub resource_status_reason: Option<String>,
    pub resource_type: String,
    pub stack_id: Option<String>,
    pub stack_name: Option<String>,
    pub timestamp: String,
}
The StackResource data type.

Fields

description: Option<String>

User defined description associated with the resource.

drift_information: Option<StackResourceDriftInformation>

Information about whether the resource's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters. For more information, see Detecting Unregulated Configuration Changes to Stacks and Resources.

logical_resource_id: String

The logical name of the resource specified in the template.

physical_resource_id: Option<String>

The name or unique identifier that corresponds to a physical instance ID of a resource supported by AWS CloudFormation.

resource_status: String

Current status of the resource.

resource_status_reason: Option<String>

Success/failure message associated with the resource.

resource_type: String

Type of resource. (For more information, go to AWS Resource Types Reference in the AWS CloudFormation User Guide.)

stack_id: Option<String>

Unique identifier of the stack.

stack_name: Option<String>

The name associated with the stack.

timestamp: String

Time the status was updated.