pub struct StackSetSummary {
pub auto_deployment: Option<AutoDeployment>,
pub description: Option<String>,
pub drift_status: Option<String>,
pub last_drift_check_timestamp: Option<String>,
pub permission_model: Option<String>,
pub stack_set_id: Option<String>,
pub stack_set_name: Option<String>,
pub status: Option<String>,
}Expand description
The structures that contain summary information about the specified stack set.
Fields
auto_deployment: Option<AutoDeployment>[Service-managed permissions] Describes whether StackSets automatically deploys to AWS Organizations accounts that are added to a target organizational unit (OU).
description: Option<String>A description of the stack set that you specify when the stack set is created or updated.
drift_status: Option<String>Status of the stack set's actual configuration compared to its expected template and parameter configuration. A stack set is considered to have drifted if one or more of its stack instances have drifted from their expected template and parameter configuration.
-
DRIFTED: One or more of the stack instances belonging to the stack set stack differs from the expected template and parameter configuration. A stack instance is considered to have drifted if one or more of the resources in the associated stack have drifted. -
NOTCHECKED: AWS CloudFormation has not checked the stack set for drift. -
INSYNC: All of the stack instances belonging to the stack set stack match from the expected template and parameter configuration. -
UNKNOWN: This value is reserved for future use.
last_drift_check_timestamp: Option<String>Most recent time when CloudFormation performed a drift detection operation on the stack set. This value will be NULL for any stack set on which drift detection has not yet been performed.
permission_model: Option<String>Describes how the IAM roles required for stack set operations are created.
-
With
self-managedpermissions, you must create the administrator and execution roles required to deploy to target accounts. For more information, see Grant Self-Managed Stack Set Permissions. -
With
service-managedpermissions, StackSets automatically creates the IAM roles required to deploy to accounts managed by AWS Organizations. For more information, see Grant Service-Managed Stack Set Permissions.
stack_set_id: Option<String>The ID of the stack set.
stack_set_name: Option<String>The name of the stack set.
status: Option<String>The status of the stack set.