pub struct Tag {
pub key: String,
pub value: String,
}Expand description
The Tag type enables you to specify a key-value pair that can be used to store information about an AWS CloudFormation stack.
Fields
key: String Required. A string used to identify this tag. You can specify a maximum of 128 characters for a tag key. Tags owned by Amazon Web Services (AWS) have the reserved prefix: aws:.
value: StringRequired. A string containing the value for this tag. You can specify a maximum of 256 characters for a tag value.