pub struct DetectStackResourceDriftOutput {
pub stack_resource_drift: StackResourceDrift,
}Fields
stack_resource_drift: StackResourceDriftInformation about whether the resource's actual configuration has drifted from its expected template configuration, including actual and expected property values and any differences detected.