pub struct StackResourceDrift {
pub actual_properties: Option<String>,
pub expected_properties: Option<String>,
pub logical_resource_id: String,
pub physical_resource_id: Option<String>,
pub physical_resource_id_context: Option<Vec<PhysicalResourceIdContextKeyValuePair>>,
pub property_differences: Option<Vec<PropertyDifference>>,
pub resource_type: String,
pub stack_id: String,
pub stack_resource_drift_status: String,
pub timestamp: String,
}Expand description
Contains the drift information for a resource that has been checked for drift. This includes actual and expected property values for resources in which AWS CloudFormation has detected drift. Only resource properties explicitly defined in the stack template are checked for drift. For more information, see Detecting Unregulated Configuration Changes to Stacks and Resources.
Resources that do not currently support drift detection cannot be checked. For a list of resources that support drift detection, see Resources that Support Drift Detection.
Use DetectStackResourceDrift to detect drift on individual resources, or DetectStackDrift to detect drift on all resources in a given stack that support drift detection.
Fields
actual_properties: Option<String>A JSON structure containing the actual property values of the stack resource.
For resources whose StackResourceDriftStatus is DELETED, this structure will not be present.
expected_properties: Option<String>A JSON structure containing the expected property values of the stack resource, as defined in the stack template and any values specified as template parameters.
For resources whose StackResourceDriftStatus is DELETED, this structure will not be present.
logical_resource_id: StringThe logical name of the resource specified in the template.
physical_resource_id: Option<String>The name or unique identifier that corresponds to a physical instance ID of a resource supported by AWS CloudFormation.
physical_resource_id_context: Option<Vec<PhysicalResourceIdContextKeyValuePair>>Context information that enables AWS CloudFormation to uniquely identify a resource. AWS CloudFormation uses context key-value pairs in cases where a resource's logical and physical IDs are not enough to uniquely identify that resource. Each context key-value pair specifies a unique resource that contains the targeted resource.
property_differences: Option<Vec<PropertyDifference>>A collection of the resource properties whose actual values differ from their expected values. These will be present only for resources whose StackResourceDriftStatus is MODIFIED.
resource_type: StringThe type of the resource.
stack_id: StringThe ID of the stack.
stack_resource_drift_status: StringStatus of the resource's actual configuration compared to its expected configuration
-
DELETED: The resource differs from its expected template configuration because the resource has been deleted. -
MODIFIED: One or more resource properties differ from their expected values (as defined in the stack template and any values specified as template parameters). -
INSYNC: The resources's actual configuration matches its expected template configuration. -
NOTCHECKED: AWS CloudFormation does not currently return this value.
timestamp: StringTime at which AWS CloudFormation performed drift detection on the stack resource.